@@ -11,26 +11,26 @@ var images decode.Group
 
 var pictureTypeNames = scalar.UToSymStr{
 	0:  "Other",
-	1:  "32x32 pixels 'file icon' (PNG only)",
-	2:  "Other file icon",
-	3:  "Cover (front)",
-	4:  "Cover (back)",
-	5:  "Leaflet page",
-	6:  "Media (e.g. label side of CD)",
-	7:  "Lead artist/lead performer/soloist",
-	8:  "Artist/performer",
-	9:  "Conductor",
-	10: "Band/Orchestra",
-	11: "Composer",
-	12: "Lyricist/text writer",
-	13: "Recording Location",
-	14: "During recording",
-	15: "During performance",
-	16: "Movie/video screen capture",
-	17: "A bright colored fish",
-	18: "Illustration",
-	19: "Band/artist logotype",
-	20: "Publisher/Studio logotype",
+	1:  "32x32_pixels",
+	2:  "other_file_icon",
+	3:  "cover_front)",
+	4:  "cover_back",
+	5:  "leaflet_page",
+	6:  "media",
+	7:  "lead_artist",
+	8:  "artist",
+	9:  "conductor",
+	10: "band",
+	11: "composer",
+	12: "lyricist",
+	13: "recording_location",
+	14: "during_recording",
+	15: "during_performance",
+	16: "movie",
+	17: "a_bright_colored_fish",
+	18: "illustration",
+	19: "artist_logotype",
+	20: "publisher_logotype",
 }
 
 func init() {
@@ -57,9 +57,7 @@ func pictureDecode(d *decode.D, in interface{}) interface{} {
 	d.FieldU32("color_depth")
 	d.FieldU32("number_of_index_colors")
 	pictureLen := d.FieldU32("picture_length")
-	if dv, _, _ := d.TryFieldFormatLen("picture_data", int64(pictureLen)*8, images, nil); dv == nil {
-		d.FieldRawLen("picture_data", int64(pictureLen)*8)
-	}
+	d.FieldFormatOrRawLen("picture_data", int64(pictureLen)*8, images, nil)
 
 	return nil
 }
