@@ -24,7 +24,7 @@ func streaminfoDecode(d *decode.D, in interface{}) interface{} {
 	// <3> (number of channels)-1. FLAC supports from 1 to 8 channels
 	d.FieldU3("channels", scalar.UAdd(1))
 	// <5> (bits per sample)-1. FLAC supports from 4 to 32 bits per sample. Currently the reference encoder and decoders only support up to 24 bits per sample.
-	bitPerSample := d.FieldU5("bits_per_sample", scalar.UAdd(1))
+	bitsPerSample := d.FieldU5("bits_per_sample", scalar.UAdd(1))
 	totalSamplesInStream := d.FieldU("total_samples_in_stream", 36)
 	md5BR := d.FieldRawLen("md5", 16*8, scalar.RawHex)
 	md5b := d.MustReadAllBits(md5BR)
@@ -32,7 +32,7 @@ func streaminfoDecode(d *decode.D, in interface{}) interface{} {
 	return format.FlacStreaminfoOut{
 		StreamInfo: format.FlacStreamInfo{
 			SampleRate:           sampleRate,
-			BitPerSample:         bitPerSample,
+			BitsPerSample:        bitsPerSample,
 			TotalSamplesInStream: totalSamplesInStream,
 			MD5:                  md5b,
 		},
