@@ -5,14 +5,17 @@ const (
 	ALL = "all"
 
 	IMAGE       = "image"
-	LINK_FRAME  = "link_frame"
 	PROBE       = "probe"
-	TCP_STREAM  = "tcp_stream"
-	UDP_PAYLOAD = "udp_payload"
+	LINK_FRAME  = "link_frame"  // ex: ethernet
+	INET_PACKET = "inet_packet" // ex: ipv4
+	IP_PACKET   = "ip_packet"   // ex: tcp
+	TCP_STREAM  = "tcp_stream"  // ex: http
+	UDP_PAYLOAD = "udp_payload" // ex: dns
 
 	AAC_FRAME           = "aac_frame"
 	ADTS                = "adts"
 	ADTS_FRAME          = "adts_frame"
+	AMF0                = "amf0"
 	APEV2               = "apev2"
 	AR                  = "ar"
 	ASN1_BER            = "asn1_ber"
@@ -50,12 +53,17 @@ const (
 	HEVC_AU             = "hevc_au"
 	HEVC_DCR            = "hevc_dcr"
 	HEVC_NALU           = "hevc_nalu"
+	HEVC_PPS            = "hevc_pps"
+	HEVC_SPS            = "hevc_sps"
+	HEVC_VPS            = "hevc_vps"
 	ICC_PROFILE         = "icc_profile"
 	ICMP                = "icmp"
+	ICMPV6              = "icmpv6"
 	ID3V1               = "id3v1"
 	ID3V11              = "id3v11"
 	ID3V2               = "id3v2"
 	IPV4_PACKET         = "ipv4_packet"
+	IPV6_PACKET         = "ipv6_packet"
 	JPEG                = "jpeg"
 	JSON                = "json"
 	MACHO               = "macho"
@@ -80,6 +88,7 @@ const (
 	PROTOBUF_WIDEVINE   = "protobuf_widevine"
 	PSSH_PLAYREADY      = "pssh_playready"
 	RAW                 = "raw"
+	RTMP                = "rtmp"
 	SLL_PACKET          = "sll_packet"
 	SLL2_PACKET         = "sll2_packet"
 	TAR                 = "tar"
@@ -102,7 +111,7 @@ const (
 
 type FlacStreamInfo struct {
 	SampleRate           uint64
-	BitPerSample         uint64
+	BitsPerSample        uint64
 	TotalSamplesInStream uint64
 	MD5                  []byte
 }
@@ -111,12 +120,6 @@ type FlacStreaminfoOut struct {
 	StreamInfo FlacStreamInfo
 }
 
-type FlacMetadatablockStreamInfo struct {
-	SampleRate           uint64
-	BitPerSample         uint64
-	TotalSamplesInStream uint64
-}
-
 type FlacMetadatablockOut struct {
 	IsLastBlock   bool
 	HasStreamInfo bool
@@ -129,8 +132,8 @@ type FlacMetadatablocksOut struct {
 }
 
 type FlacFrameIn struct {
-	SamplesBuf []byte
-	StreamInfo FlacStreamInfo
+	SamplesBuf    []byte
+	BitsPerSample int `doc:"Bits per sample"`
 }
 
 type FlacFrameOut struct {
@@ -149,16 +152,16 @@ type OggPageOut struct {
 	Segments           [][]byte
 }
 
-type AvcIn struct {
-	LengthSize uint64
+type AvcAuIn struct {
+	LengthSize uint64 `doc:"Length value size"`
 }
 
 type AvcDcrOut struct {
 	LengthSize uint64
 }
 
-type HevcIn struct {
-	LengthSize uint64
+type HevcAuIn struct {
+	LengthSize uint64 `doc:"Length value size"`
 }
 
 type HevcDcrOut struct {
@@ -183,7 +186,12 @@ type MPEGASCOut struct {
 }
 
 type AACFrameIn struct {
-	ObjectType int
+	ObjectType int `doc:"Audio object type"`
+}
+
+type Mp3In struct {
+	MaxUniqueHeaderConfigs int `doc:"Max number of unique frame header configs allowed"`
+	MaxSyncSeek            int `doc:"Max byte distance to next sync"`
 }
 
 type MP3FrameOut struct {
@@ -195,14 +203,17 @@ type MP3FrameOut struct {
 	ChannelModeIndex int
 }
 
-type In struct {
-	SourcePort      int
-	DestinationPort int
+type LinkFrameIn struct {
+	Type           int
+	IsLittleEndian bool // pcap endian etc
 }
 
-type LinkFrameIn struct {
-	Type         int
-	LittleEndian bool // pcap endian etc
+type InetPacketIn struct {
+	EtherType int
+}
+
+type IPPacketIn struct {
+	Protocol int
 }
 
 type UDPPayloadIn struct {
@@ -210,17 +221,46 @@ type UDPPayloadIn struct {
 	DestinationPort int
 }
 
+func (u UDPPayloadIn) IsPort(ports ...int) bool {
+	for _, p := range ports {
+		if u.DestinationPort == p || u.SourcePort == p {
+			return true
+		}
+	}
+	return false
+}
+
+func (u UDPPayloadIn) MustIsPort(fn func(format string, a ...interface{}), ports ...int) {
+	if !u.IsPort(ports...) {
+		fn("incorrect udp port %t src:%d dst:%d", u.DestinationPort, u.SourcePort)
+	}
+}
+
 type TCPStreamIn struct {
+	IsClient        bool
+	HasStart        bool
+	HasEnd          bool
 	SourcePort      int
 	DestinationPort int
 }
 
-type X86_64In struct {
-	Base      int64
-	SymLookup func(uint64) (string, uint64)
+func (t TCPStreamIn) IsPort(ports ...int) bool {
+	for _, p := range ports {
+		if (t.IsClient && t.DestinationPort == p) ||
+			(!t.IsClient && t.SourcePort == p) {
+			return true
+		}
+	}
+	return false
 }
 
-type ARM64In struct {
-	Base      int64
-	SymLookup func(uint64) (string, uint64)
+func (t TCPStreamIn) MustIsPort(fn func(format string, a ...interface{}), ports ...int) {
+	if !t.IsPort(ports...) {
+		fn("incorrect tcp port client %t src:%d dst:%d", t.IsClient, t.DestinationPort, t.SourcePort)
+	}
+}
+
+type Mp4In struct {
+	DecodeSamples  bool `doc:"Decode supported media samples"`
+	AllowTruncated bool `doc:"Allow box to be truncated"`
 }
