@@ -12,7 +12,7 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
-var ether8023FrameIPv4Format decode.Group
+var ether8023FrameInetPacketGroup decode.Group
 
 func init() {
 	registry.MustRegister(decode.Format{
@@ -20,16 +20,12 @@ func init() {
 		Description: "Ethernet 802.3 frame",
 		Groups:      []string{format.LINK_FRAME},
 		Dependencies: []decode.Dependency{
-			{Names: []string{format.IPV4_PACKET}, Group: &ether8023FrameIPv4Format},
+			{Names: []string{format.INET_PACKET}, Group: &ether8023FrameInetPacketGroup},
 		},
 		DecodeFn: decodeEthernetFrame,
 	})
 }
 
-var ether8023FrameTypeFormat = map[uint64]*decode.Group{
-	format.EtherTypeIPv4: &ether8023FrameIPv4Format,
-}
-
 // TODO: move to shared?
 var mapUToEtherSym = scalar.Fn(func(s scalar.S) (scalar.S, error) {
 	var b [8]byte
@@ -39,20 +35,22 @@ var mapUToEtherSym = scalar.Fn(func(s scalar.S) (scalar.S, error) {
 })
 
 func decodeEthernetFrame(d *decode.D, in interface{}) interface{} {
-	if lsi, ok := in.(format.LinkFrameIn); ok {
-		if lsi.Type != format.LinkTypeETHERNET {
-			d.Fatalf("wrong link type")
+	if lfi, ok := in.(format.LinkFrameIn); ok {
+		if lfi.Type != format.LinkTypeETHERNET {
+			d.Fatalf("wrong link type %d", lfi.Type)
 		}
 	}
 
 	d.FieldU("destination", 48, mapUToEtherSym, scalar.Hex)
 	d.FieldU("source", 48, mapUToEtherSym, scalar.Hex)
 	etherType := d.FieldU16("ether_type", format.EtherTypeMap, scalar.Hex)
-	if g, ok := ether8023FrameTypeFormat[etherType]; ok {
-		d.FieldFormatLen("packet", d.BitsLeft(), *g, nil)
-	} else {
-		d.FieldRawLen("data", d.BitsLeft())
-	}
+
+	d.FieldFormatOrRawLen(
+		"payload",
+		d.BitsLeft(),
+		ether8023FrameInetPacketGroup,
+		format.InetPacketIn{EtherType: int(etherType)},
+	)
 
 	return nil
 }
