@@ -3,6 +3,7 @@ package macho
 // https://github.com/aidansteele/osx-abi-macho-file-format-reference
 
 import (
+	"embed"
 	"time"
 
 	"github.com/wader/fq/format"
@@ -12,12 +13,17 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
+//go:embed macho.jq
+var machoFS embed.FS
+
 func init() {
 	registry.MustRegister(decode.Format{
 		Name:        format.MACHO,
 		Description: "Mach-O macOS executable",
 		Groups:      []string{format.PROBE},
 		DecodeFn:    machoDecode,
+		Files:       machoFS,
+		Functions:   []string{"_help"},
 	})
 }
 
@@ -31,11 +37,11 @@ const (
 	FAT_CIGAM   = 0xbeba_feca
 )
 
-var magicSymMapper = scalar.UToScalar{
-	MH_MAGIC:    scalar.S{Description: "32-bit little endian"},
-	MH_CIGAM:    scalar.S{Description: "32-bit big endian"},
-	MH_MAGIC_64: scalar.S{Description: "64-bit little endian"},
-	MH_CIGAM_64: scalar.S{Description: "64-bit big endian"},
+var magicSymMapper = scalar.UToDescription{
+	MH_MAGIC:    "32-bit little endian",
+	MH_CIGAM:    "32-bit big endian",
+	MH_MAGIC_64: "64-bit little endian",
+	MH_CIGAM_64: "64-bit big endian",
 }
 
 var endianNames = scalar.UToSymStr{
@@ -46,155 +52,173 @@ var endianNames = scalar.UToSymStr{
 }
 
 var cpuTypes = scalar.UToSymStr{
-	0xff_ff_ff_ff: "CPU_TYPE_ANY",
-	1:             "CPU_TYPE_VAX",
-	2:             "CPU_TYPE_ROMP",
-	4:             "CPU_TYPE_NS32032",
-	5:             "CPU_TYPE_NS32332",
-	6:             "CPU_TYPE_MC680x0",
-	7:             "CPU_TYPE_X86",
-	8:             "CPU_TYPE_MIPS",
-	9:             "CPU_TYPE_NS32532",
-	10:            "CPU_TYPE_MC98000",
-	11:            "CPU_TYPE_HPPA",
-	12:            "CPU_TYPE_ARM",
-	13:            "CPU_TYPE_MC88000",
-	14:            "CPU_TYPE_SPARC",
-	15:            "CPU_TYPE_I860",
-	16:            "CPU_TYPE_I860_LITTLE",
-	17:            "CPU_TYPE_RS6000",
-	18:            "CPU_TYPE_POWERPC",
-	0x1000007:     "CPU_TYPE_X86_64",
-	0x100000c:     "CPU_TYPE_ARM64",
-	0x1000013:     "CPU_TYPE_POWERPC64",
-	255:           "CPU_TYPE_VEO",
+	0xff_ff_ff_ff: "any",
+	1:             "vax",
+	2:             "romp",
+	4:             "ns32032",
+	5:             "ns32332",
+	6:             "mc680x0",
+	7:             "x86",
+	8:             "mips",
+	9:             "ns32532",
+	10:            "mc98000",
+	11:            "hppa",
+	12:            "arm",
+	13:            "mc88000",
+	14:            "sparc",
+	15:            "i860",
+	16:            "i860_little",
+	17:            "rs6000",
+	18:            "powerpc",
+	0x1000007:     "x86_64",
+	0x100000c:     "arm64",
+	0x1000013:     "powerpc64",
+	255:           "veo",
+}
+
+func intelSubTypeHelper(f, m uint64) uint64 {
+	return f + (m << 4)
 }
 
 var cpuSubTypes = map[uint64]scalar.UToSymStr{
 	0xff_ff_ff_ff: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
+		0xff_ff_ff_ff: "multiple",
 	},
 	1: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_VAX_ALL",
-		1:             "CPU_SUBTYPE_VAX780",
-		2:             "CPU_SUBTYPE_VAX785",
-		3:             "CPU_SUBTYPE_VAX750",
-		4:             "CPU_SUBTYPE_VAX730",
-		5:             "CPU_SUBTYPE_UVAXI",
-		6:             "CPU_SUBTYPE_UVAXII",
-		7:             "CPU_SUBTYPE_VAX8200",
-		8:             "CPU_SUBTYPE_VAX8500",
-		9:             "CPU_SUBTYPE_VAX8600",
-		10:            "CPU_SUBTYPE_VAX8650",
-		11:            "CPU_SUBTYPE_VAX8800",
-		12:            "CPU_SUBTYPE_UVAXIII",
+		0xff_ff_ff_ff: "multiple",
+		0:             "vax_all",
+		1:             "vax780",
+		2:             "vax785",
+		3:             "vax750",
+		4:             "vax730",
+		5:             "uvaxi",
+		6:             "uvaxii",
+		7:             "vax8200",
+		8:             "vax8500",
+		9:             "vax8600",
+		10:            "vax8650",
+		11:            "vax8800",
+		12:            "uvaxiii",
 	},
 	6: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		1:             "CPU_SUBTYPE_MC680X0_ALL", // 1: CPU_SUBTYPE_MC68030
-		2:             "CPU_SUBTYPE_MC68040",
-		3:             "CPU_SUBTYPE_MC68030_ONLY",
+		0xff_ff_ff_ff: "multiple",
+		1:             "mc680x0_all", // 1: mc68030
+		2:             "mc68040",
+		3:             "mc68030_only",
 	},
 	7: {
-		0xff_ff_ff_ff:             "CPU_SUBTYPE_MULTIPLE",
-		intelSubTypeHelper(3, 0):  "CPU_SUBTYPE_I386_ALL", // CPU_SUBTYPE_I386
-		intelSubTypeHelper(4, 0):  "CPU_SUBTYPE_I486",
-		intelSubTypeHelper(4, 8):  "CPU_SUBTYPE_486SX",
-		intelSubTypeHelper(5, 0):  "CPU_SUBTYPE_PENT",
-		intelSubTypeHelper(6, 1):  "CPU_SUBTYPE_PENTPRO",
-		intelSubTypeHelper(6, 3):  "CPU_SUBTYPE_PENTII_M3",
-		intelSubTypeHelper(6, 5):  "CPU_SUBTYPE_PENTII_M5",
-		intelSubTypeHelper(7, 6):  "CPU_SUBTYPE_CELERON",
-		intelSubTypeHelper(7, 7):  "CPU_SUBTYPE_CELERON_MOBILE",
-		intelSubTypeHelper(8, 0):  "CPU_SUBTYPE_PENTIUM_3",
-		intelSubTypeHelper(8, 1):  "CPU_SUBTYPE_PENTIUM_3_M",
-		intelSubTypeHelper(8, 2):  "CPU_SUBTYPE_PENTIUM_3_XEON",
-		intelSubTypeHelper(9, 0):  "CPU_SUBTYPE_PENTIUM_M",
-		intelSubTypeHelper(10, 0): "CPU_SUBTYPE_PENTIUM_4",
-		intelSubTypeHelper(10, 1): "CPU_SUBTYPE_PENTIUM_4_M",
-		intelSubTypeHelper(11, 0): "CPU_SUBTYPE_ITANIUM",
-		intelSubTypeHelper(11, 1): "CPU_SUBTYPE_ITANIUM_2",
-		intelSubTypeHelper(12, 0): "CPU_SUBTYPE_XEON",
-		intelSubTypeHelper(12, 1): "CPU_SUBTYPE_XEON_2",
+		0xff_ff_ff_ff:             "multiple",
+		intelSubTypeHelper(3, 0):  "i386_all", // i386
+		intelSubTypeHelper(4, 0):  "i486",
+		intelSubTypeHelper(4, 8):  "486sx",
+		intelSubTypeHelper(5, 0):  "pent",
+		intelSubTypeHelper(6, 1):  "pentpro",
+		intelSubTypeHelper(6, 3):  "pentii_m3",
+		intelSubTypeHelper(6, 5):  "pentii_m5",
+		intelSubTypeHelper(7, 6):  "celeron",
+		intelSubTypeHelper(7, 7):  "celeron_mobile",
+		intelSubTypeHelper(8, 0):  "pentium_3",
+		intelSubTypeHelper(8, 1):  "pentium_3_m",
+		intelSubTypeHelper(8, 2):  "pentium_3_xeon",
+		intelSubTypeHelper(9, 0):  "pentium_m",
+		intelSubTypeHelper(10, 0): "pentium_4",
+		intelSubTypeHelper(10, 1): "pentium_4_m",
+		intelSubTypeHelper(11, 0): "itanium",
+		intelSubTypeHelper(11, 1): "itanium_2",
+		intelSubTypeHelper(12, 0): "xeon",
+		intelSubTypeHelper(12, 1): "xeon_2",
 	},
 	8: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_MIPS_ALL",
-		1:             "CPU_SUBTYPE_MIPS_R2300",
-		2:             "CPU_SUBTYPE_MIPS_R2600",
-		3:             "CPU_SUBTYPE_MIPS_R2800",
-		4:             "CPU_SUBTYPE_MIPS_R2000A",
-		5:             "CPU_SUBTYPE_MIPS_R2000",
-		6:             "CPU_SUBTYPE_MIPS_R3000A",
-		7:             "CPU_SUBTYPE_MIPS_R3000",
+		0xff_ff_ff_ff: "multiple",
+		0:             "mips_all",
+		1:             "mips_r2300",
+		2:             "mips_r2600",
+		3:             "mips_r2800",
+		4:             "mips_r2000a",
+		5:             "mips_r2000",
+		6:             "mips_r3000a",
+		7:             "mips_r3000",
 	},
 	10: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_MC98000_ALL",
-		1:             "CPU_SUBTYPE_MC98001",
+		0xff_ff_ff_ff: "multiple",
+		0:             "mc98000_all",
+		1:             "mc98001",
 	},
 	11: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_HPPA_ALL",
-		1:             "CPU_SUBTYPE_HPPA_7100",
-		2:             "CPU_SUBTYPE_HPPA_7100_LC",
+		0xff_ff_ff_ff: "multiple",
+		0:             "hppa_all",
+		1:             "hppa_7100",
+		2:             "hppa_7100_lc",
 	},
 	12: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_ARM_ALL",
-		5:             "CPU_SUBTYPE_ARM_V4T",
-		6:             "CPU_SUBTYPE_ARM_V6",
-		7:             "CPU_SUBTYPE_ARM_V5TEJ",
-		8:             "CPU_SUBTYPE_ARM_XSCALE",
-		9:             "CPU_SUBTYPE_ARM_V7",
-		10:            "CPU_SUBTYPE_ARM_V7F",
-		11:            "CPU_SUBTYPE_ARM_V7S",
-		12:            "CPU_SUBTYPE_ARM_V7K",
-		13:            "CPU_SUBTYPE_ARM_V8",
-		14:            "CPU_SUBTYPE_ARM_V6M",
-		15:            "CPU_SUBTYPE_ARM_V7M",
-		16:            "CPU_SUBTYPE_ARM_V7EM",
+		0xff_ff_ff_ff: "multiple",
+		0:             "arm_all",
+		5:             "arm_v4t",
+		6:             "arm_v6",
+		7:             "arm_v5tej",
+		8:             "arm_xscale",
+		9:             "arm_v7",
+		10:            "arm_v7f",
+		11:            "arm_v7s",
+		12:            "arm_v7k",
+		13:            "arm_v8",
+		14:            "arm_v6m",
+		15:            "arm_v7m",
+		16:            "arm_v7em",
 	},
 	13: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_MC88000_ALL",
-		1:             "CPU_SUBTYPE_MC88100",
-		2:             "CPU_SUBTYPE_MC88110",
+		0xff_ff_ff_ff: "multiple",
+		0:             "mc88000_all",
+		1:             "mc88100",
+		2:             "mc88110",
 	},
 	14: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_SPARC_ALL",
+		0xff_ff_ff_ff: "multiple",
+		0:             "sparc_all",
 	},
 	15: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_I860_ALL",
-		1:             "CPU_SUBTYPE_I860_A860",
+		0xff_ff_ff_ff: "multiple",
+		0:             "i860_all",
+		1:             "i860_a860",
 	},
 	18: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_POWERPC_ALL",
-		1:             "CPU_SUBTYPE_POWERPC_601",
-		2:             "CPU_SUBTYPE_POWERPC_602",
-		3:             "CPU_SUBTYPE_POWERPC_603",
-		4:             "CPU_SUBTYPE_POWERPC_603E",
-		5:             "CPU_SUBTYPE_POWERPC_603EV",
-		6:             "CPU_SUBTYPE_POWERPC_604",
-		7:             "CPU_SUBTYPE_POWERPC_604E",
-		8:             "CPU_SUBTYPE_POWERPC_620",
-		9:             "CPU_SUBTYPE_POWERPC_750",
-		10:            "CPU_SUBTYPE_POWERPC_7400",
-		11:            "CPU_SUBTYPE_POWERPC_7450",
-		100:           "CPU_SUBTYPE_POWERPC_970",
+		0xff_ff_ff_ff: "multiple",
+		0:             "powerpc_all",
+		1:             "powerpc_601",
+		2:             "powerpc_602",
+		3:             "powerpc_603",
+		4:             "powerpc_603e",
+		5:             "powerpc_603ev",
+		6:             "powerpc_604",
+		7:             "powerpc_604e",
+		8:             "powerpc_620",
+		9:             "powerpc_750",
+		10:            "powerpc_7400",
+		11:            "powerpc_7450",
+		100:           "powerpc_970",
 	},
 	0x1000012: {
-		0xff_ff_ff_ff: "CPU_SUBTYPE_MULTIPLE",
-		0:             "CPU_SUBTYPE_ARM64_ALL",
-		1:             "CPU_SUBTYPE_ARM64_V8",
-		2:             "CPU_SUBTYPE_ARM64_E",
+		0xff_ff_ff_ff: "multiple",
+		0:             "arm64_all",
+		1:             "arm64_v8",
+		2:             "arm64_e",
 	},
 }
 
+var fileTypes = scalar.UToSymStr{
+	0x1: "object",
+	0x2: "execute",
+	0x3: "fvmlib",
+	0x4: "core",
+	0x5: "preload",
+	0x6: "dylib",
+	0x7: "dylinker",
+	0x8: "bundle",
+	0x9: "dylib_stub",
+	0xa: "dsym",
+	0xb: "kext_bundle",
+}
+
 //nolint:revive
 const (
 	LC_REQ_DYLD                 = 0x80000000
@@ -240,31 +264,17 @@ const (
 	LC_DYLD_ENVIRONMENT         = 0x27
 	LC_MAIN                     = 0x80000028
 	LC_DATA_IN_CODE             = 0x29
-	LC_SOURCE_VERSION           = 0x2A
-	LC_DYLIB_CODE_SIGN_DRS      = 0x2B
-	LC_ENCRYPTION_INFO_64       = 0x2C
-	LC_LINKER_OPTION            = 0x2D
-	LC_LINKER_OPTIMIZATION_HINT = 0x2E
-	LC_VERSION_MIN_TVOS         = 0x2F
+	LC_SOURCE_VERSION           = 0x2a
+	LC_DYLIB_CODE_SIGN_DRS      = 0x2b
+	LC_ENCRYPTION_INFO_64       = 0x2c
+	LC_LINKER_OPTION            = 0x2d
+	LC_LINKER_OPTIMIZATION_HINT = 0x2e
+	LC_VERSION_MIN_TVOS         = 0x2f
 	LC_VERSION_MIN_WATCHOS      = 0x30
 	LC_NOTE                     = 0x31 // not implemented
 	LC_BUILD_VERSION            = 0x32
 )
 
-var fileTypes = scalar.UToSymStr{
-	0x1: "MH_OBJECT",
-	0x2: "MH_EXECUTE",
-	0x3: "MH_FVMLIB",
-	0x4: "MH_CORE",
-	0x5: "MH_PRELOAD",
-	0x6: "MH_DYLIB",
-	0x7: "MH_DYLINKER",
-	0x8: "MH_BUNDLE",
-	0x9: "MH_DYLIB_STUB",
-	0xa: "MH_DSYM",
-	0xb: "MH_KEXT_BUNDLE",
-}
-
 var loadCommands = scalar.UToSymStr{
 	LC_REQ_DYLD:                 "req_dyld",
 	LC_SEGMENT:                  "segment",
@@ -321,28 +331,28 @@ var loadCommands = scalar.UToSymStr{
 }
 
 var sectionTypes = scalar.UToSymStr{
-	0x0:  "S_REGULAR",
-	0x1:  "S_ZEROFILL",
-	0x2:  "S_CSTRING_LITERALS",
-	0x3:  "S_4BYTE_LITERALS",
-	0x4:  "S_8BYTE_LITERALS",
-	0x5:  "S_LITERAL_POINTERS",
-	0x6:  "S_NON_LAZY_SYMBOL_POINTERS",
-	0x7:  "S_LAZY_SYMBOL_POINTERS",
-	0x8:  "S_SYMBOL_STUBS",
-	0x9:  "S_MOD_INIT_FUNC_POINTERS",
-	0xa:  "S_MOD_TERM_FUNC_POINTERS",
-	0xb:  "S_COALESCED",
-	0xc:  "S_GB_ZEROFILL",
-	0xd:  "S_INTERPOSING",
-	0xe:  "S_16BYTE_LITERALS",
-	0xf:  "S_DTRACE_DOF",
-	0x10: "S_LAZY_DYLIB_SYMBOL_POINTERS",
-	0x11: "S_THREAD_LOCAL_REGULAR",
-	0x12: "S_THREAD_LOCAL_ZEROFILL",
-	0x13: "S_THREAD_LOCAL_VARIABLES",
-	0x14: "S_THREAD_LOCAL_VARIABLE_POINTERS",
-	0x15: "S_THREAD_LOCAL_INIT_FUNCTION_POINTERS",
+	0x0:  "regular",
+	0x1:  "zerofill",
+	0x2:  "cstring_literals",
+	0x3:  "4byte_literals",
+	0x4:  "8byte_literals",
+	0x5:  "literal_pointers",
+	0x6:  "non_lazy_symbol_pointers",
+	0x7:  "lazy_symbol_pointers",
+	0x8:  "symbol_stubs",
+	0x9:  "mod_init_func_pointers",
+	0xa:  "mod_term_func_pointers",
+	0xb:  "coalesced",
+	0xc:  "gb_zerofill",
+	0xd:  "interposing",
+	0xe:  "16byte_literals",
+	0xf:  "dtrace_dof",
+	0x10: "lazy_dylib_symbol_pointers",
+	0x11: "thread_local_regular",
+	0x12: "thread_local_zerofill",
+	0x13: "thread_local_variables",
+	0x14: "thread_local_variable_pointers",
+	0x15: "thread_local_init_function_pointers",
 }
 
 func machoDecode(d *decode.D, in interface{}) interface{} {
@@ -386,11 +396,11 @@ func ofileDecode(d *decode.D) {
 	d.SeekRel(-4 * 8)
 	d.FieldStruct("header", func(d *decode.D) {
 		d.FieldValueS("arch_bits", int64(archBits))
-		magic := d.FieldU32("magic", scalar.Hex, magicSymMapper)
+		magic := d.FieldU32("magic", magicSymMapper, scalar.Hex)
 		d.FieldValueU("bits", uint64(archBits))
 		d.FieldValueStr("endian", endianNames[magic])
-		cpuType = d.FieldU32("cputype", cpuTypes)
-		d.FieldU32("cpusubtype", cpuSubTypes[cpuType])
+		cpuType = d.FieldU32("cputype", cpuTypes, scalar.Hex)
+		d.FieldU32("cpusubtype", cpuSubTypes[cpuType], scalar.Hex)
 		d.FieldU32("filetype", fileTypes)
 		ncmds = d.FieldU32("ncdms")
 		d.FieldU32("sizeofncdms")
@@ -440,14 +450,15 @@ func ofileDecode(d *decode.D) {
 					// OPCODE_DECODER sectname==__text
 					d.FieldUTF8NullFixedLen("sectname", 16)
 					d.FieldUTF8NullFixedLen("segname", 16)
+					var size uint64
 					if archBits == 32 {
 						d.FieldU32("address", scalar.Hex)
-						d.FieldU32("size")
+						size = d.FieldU32("size")
 					} else {
 						d.FieldU64("address", scalar.Hex)
-						d.FieldU64("size")
+						size = d.FieldU64("size")
 					}
-					d.FieldU32("offset")
+					offset := d.FieldU32("offset")
 					d.FieldU32("align")
 					d.FieldU32("reloff")
 					d.FieldU32("nreloc")
@@ -459,6 +470,9 @@ func ofileDecode(d *decode.D) {
 					if archBits == 64 {
 						d.FieldU32("reserved3")
 					}
+					d.RangeFn(int64(offset)*8, int64(size)*8, func(d *decode.D) {
+						d.FieldRawLen("data", d.BitsLeft())
+					})
 					nsectIdx++
 				})
 		case LC_TWOLEVEL_HINTS:
@@ -606,9 +620,12 @@ func ofileDecode(d *decode.D) {
 			})
 		case LC_ENCRYPTION_INFO, LC_ENCRYPTION_INFO_64:
 			d.FieldStruct("encryption_info", func(d *decode.D) {
-				d.FieldU32("offset")
-				d.FieldU32("size")
+				offset := d.FieldU32("offset")
+				size := d.FieldU32("size")
 				d.FieldU32("id")
+				d.RangeFn(int64(offset)*8, int64(size)*8, func(d *decode.D) {
+					d.FieldRawLen("data", d.BitsLeft())
+				})
 			})
 		case LC_IDFVMLIB, LC_LOADFVMLIB:
 			d.FieldStruct("fvmlib", func(d *decode.D) {
@@ -633,22 +650,20 @@ func fatParse(d *decode.D) {
 	var narchs uint64
 	var ofileOffsets []uint64
 	d.FieldStruct("fat_header", func(d *decode.D) {
-		d.FieldRawLen("magic", 4*8)
+		d.FieldU32("magic", scalar.Hex)
 		narchs = d.FieldU32("narchs")
 		narchsIdx := 0
 
-		d.FieldStructArrayLoop("archs", "arch", func() bool {
+		d.FieldStructArrayLoop("archs", "fat_arch", func() bool {
 			return narchsIdx < int(narchs)
 		}, func(d *decode.D) {
 			// parse FatArch
-			d.FieldStruct("fat_arch", func(d *decode.D) {
-				// beware cputype and cpusubtype changes from ofile header to fat header
-				cpuType := d.FieldU32("cputype", cpuTypes)
-				d.FieldU32("cpusubtype", cpuSubTypes[cpuType])
-				ofileOffsets = append(ofileOffsets, d.FieldU32("offset"))
-				d.FieldU32("size")
-				d.FieldU32("align")
-			})
+			// beware cputype and cpusubtype changes from ofile header to fat header
+			cpuType := d.FieldU32("cputype", cpuTypes, scalar.Hex)
+			d.FieldU32("cpusubtype", cpuSubTypes[cpuType], scalar.Hex)
+			ofileOffsets = append(ofileOffsets, d.FieldU32("offset"))
+			d.FieldU32("size")
+			d.FieldU32("align")
 			narchsIdx++
 		})
 	})
@@ -662,68 +677,64 @@ func fatParse(d *decode.D) {
 	})
 }
 
-func intelSubTypeHelper(f, m uint64) uint64 {
-	return f + (m << 4)
-}
-
 func parseMachHeaderFlags(d *decode.D) {
 	d.FieldRawLen("reserved", 6)
-	d.FieldBool("MH_APP_EXTENSION_SAFE")
-	d.FieldBool("MH_NO_HEAP_EXECUTION")
+	d.FieldBool("app_extension_safe")
+	d.FieldBool("no_heap_execution")
 
-	d.FieldBool("MH_HAS_TLV_DESCRIPTORS")
-	d.FieldBool("MH_DEAD_STRIPPABLE_DYLIB")
-	d.FieldBool("MH_PIE")
-	d.FieldBool("MH_NO_REEXPORTED_DYLIBS")
+	d.FieldBool("has_tlv_descriptors")
+	d.FieldBool("dead_strippable_dylib")
+	d.FieldBool("pie")
+	d.FieldBool("no_reexported_dylibs")
 
-	d.FieldBool("MH_SETUID_SAFE")
-	d.FieldBool("MH_ROOT_SAFE")
-	d.FieldBool("MH_ALLOW_STACK_EXECUTION")
-	d.FieldBool("MH_BINDS_TO_WEAK")
+	d.FieldBool("setuid_safe")
+	d.FieldBool("root_safe")
+	d.FieldBool("allow_stack_execution")
+	d.FieldBool("binds_to_weak")
 
-	d.FieldBool("MH_WEAK_DEFINES")
-	d.FieldBool("MH_CANONICAL")
-	d.FieldBool("MH_SUBSECTIONS_VIA_SYMBOLS")
-	d.FieldBool("MH_ALLMODSBOUND")
+	d.FieldBool("weak_defines")
+	d.FieldBool("canonical")
+	d.FieldBool("subsections_via_symbols")
+	d.FieldBool("allmodsbound")
 
-	d.FieldBool("MH_PREBINDABLE")
-	d.FieldBool("MH_NOFIXPREBINDING")
-	d.FieldBool("MH_NOMULTIDEFS")
-	d.FieldBool("MH_FORCE_FLAT")
+	d.FieldBool("prebindable")
+	d.FieldBool("nofixprebinding")
+	d.FieldBool("nomultidefs")
+	d.FieldBool("force_flat")
 
-	d.FieldBool("MH_TWOLEVEL")
-	d.FieldBool("MH_LAZY_INIT")
-	d.FieldBool("MH_SPLIT_SEGS")
-	d.FieldBool("MH_PREBOUND")
+	d.FieldBool("twolevel")
+	d.FieldBool("lazy_init")
+	d.FieldBool("split_segs")
+	d.FieldBool("prebound")
 
-	d.FieldBool("MH_BINDATLOAD")
-	d.FieldBool("MH_DYLDLINK")
-	d.FieldBool("MH_INCRLINK")
-	d.FieldBool("MH_NOUNDEFS")
+	d.FieldBool("bindatload")
+	d.FieldBool("dyldlink")
+	d.FieldBool("incrlink")
+	d.FieldBool("noundefs")
 }
 
 func parseSegmentFlags(d *decode.D) {
 	d.FieldRawLen("reserved", 28)
-	d.FieldBool("SG_PROTECTED_VERSION_1")
-	d.FieldBool("SG_NORELOC")
-	d.FieldBool("SG_FVMLIB")
-	d.FieldBool("SG_HIGHVM")
+	d.FieldBool("protected_version_1")
+	d.FieldBool("noreloc")
+	d.FieldBool("fvmlib")
+	d.FieldBool("highvm")
 }
 
 func parseSectionFlags(d *decode.D) {
-	d.FieldBool("S_ATTR_PURE_INSTRUCTIONS")
-	d.FieldBool("S_ATTR_NO_TOC")
-	d.FieldBool("S_ATTR_STRIP_STATIC_SYMS")
-	d.FieldBool("S_ATTR_NO_DEAD_STRIP")
+	d.FieldBool("attr_pure_instructions")
+	d.FieldBool("attr_no_toc")
+	d.FieldBool("attr_strip_static_syms")
+	d.FieldBool("attr_no_dead_strip")
 
-	d.FieldBool("S_ATTR_LIVE_SUPPORT")
-	d.FieldBool("S_ATTR_SELF_MODIFYING_CODE")
-	d.FieldBool("S_ATTR_DEBUG")
+	d.FieldBool("attr_live_support")
+	d.FieldBool("attr_self_modifying_code")
+	d.FieldBool("attr_debug")
 	d.FieldRawLen("reserved", 14)
 
-	d.FieldBool("S_ATTR_SOME_INSTRUCTIONS")
-	d.FieldBool("S_ATTR_EXT_RELOC")
-	d.FieldBool("S_ATTR_LOC_RELOC")
+	d.FieldBool("attr_some_instructions")
+	d.FieldBool("attr_ext_reloc")
+	d.FieldBool("attr_loc_reloc")
 }
 
 var timestampMapper = scalar.Fn(func(s scalar.S) (scalar.S, error) {
