@@ -25,7 +25,7 @@ import (
 	"github.com/wader/fq/pkg/decode"
 )
 
-//go:embed *.jq
+//go:embed mp4.jq
 var mp4FS embed.FS
 
 var aacFrameFormat decode.Group
@@ -54,12 +54,16 @@ var iccProfileFormat decode.Group
 func init() {
 	registry.MustRegister(decode.Format{
 		Name:        format.MP4,
-		Description: "MPEG-4 file and similar",
+		Description: "ISOBMFF MPEG-4 part 12 and similar",
 		Groups: []string{
 			format.PROBE,
 			format.IMAGE, // avif
 		},
 		DecodeFn: mp4Decode,
+		DecodeInArg: format.Mp4In{
+			DecodeSamples:  true,
+			AllowTruncated: false,
+		},
 		Dependencies: []decode.Dependency{
 			{Names: []string{format.AAC_FRAME}, Group: &aacFrameFormat},
 			{Names: []string{format.AV1_CCR}, Group: &av1CCRFormat},
@@ -84,7 +88,8 @@ func init() {
 			{Names: []string{format.VPX_CCR}, Group: &vpxCCRFormat},
 			{Names: []string{format.ICC_PROFILE}, Group: &iccProfileFormat},
 		},
-		Files: mp4FS,
+		Files:     mp4FS,
+		Functions: []string{"_help"},
 	})
 }
 
@@ -125,44 +130,28 @@ type track struct {
 	currentMoof *moof
 }
 
+type pathEntry struct {
+	typ  string
+	data interface{}
+}
+
 type decodeContext struct {
-	path              []string
+	opts              format.Mp4In
+	path              []pathEntry
 	tracks            map[uint32]*track
 	currentTrack      *track
 	currentMoofOffset int64
 }
 
-func isParent(ctx *decodeContext, typ string) bool {
-	return len(ctx.path) >= 2 && ctx.path[len(ctx.path)-2] == typ
+func (ctx *decodeContext) isParent(typ string) bool {
+	return ctx.parent().typ == typ
 }
 
-func mp4Decode(d *decode.D, in interface{}) interface{} {
-	ctx := &decodeContext{
-		tracks: map[uint32]*track{},
-	}
-
-	// TODO: nicer, validate functions without field?
-	d.AssertLeastBytesLeft(16)
-	size := d.U32()
-	if size < 8 {
-		d.Fatalf("first box size too small < 8")
-	}
-	firstType := d.UTF8(4)
-	switch firstType {
-	case "styp", // mp4 segment
-		"ftyp", // mp4 file
-		"free", // seems to happen
-		"moov", // seems to happen
-		"pnot", // video preview file
-		"jP  ": // JPEG 2000
-	default:
-		d.Errorf("no styp, ftyp, free or moov box found")
-	}
-
-	d.SeekRel(-8 * 8)
-
-	decodeBoxes(ctx, d)
+func (ctx *decodeContext) parent() pathEntry {
+	return ctx.path[len(ctx.path)-2]
+}
 
+func mp4Tracks(d *decode.D, ctx *decodeContext) {
 	// keep track order stable
 	var sortedTracks []*track
 	for _, t := range ctx.tracks {
@@ -174,6 +163,11 @@ func mp4Decode(d *decode.D, in interface{}) interface{} {
 		for _, t := range sortedTracks {
 			decodeSampleRange := func(d *decode.D, t *track, dataFormat string, name string, firstBit int64, nBits int64, inArg interface{}) {
 				d.RangeFn(firstBit, nBits, func(d *decode.D) {
+					if !ctx.opts.DecodeSamples {
+						d.FieldRawLen(name, d.BitsLeft())
+						return
+					}
+
 					switch {
 					case dataFormat == "fLaC":
 						d.FieldFormatLen(name, nBits, flacFrameFormat, inArg)
@@ -304,7 +298,41 @@ func mp4Decode(d *decode.D, in interface{}) interface{} {
 			})
 		}
 	})
+}
+
+func mp4Decode(d *decode.D, in interface{}) interface{} {
+	mi, _ := in.(format.Mp4In)
+
+	ctx := &decodeContext{
+		opts:   mi,
+		path:   []pathEntry{{typ: "root"}},
+		tracks: map[uint32]*track{},
+	}
+
+	// TODO: nicer, validate functions without field?
+	d.AssertLeastBytesLeft(16)
+	size := d.U32()
+	if size < 8 {
+		d.Fatalf("first box size too small < 8")
+	}
+	firstType := d.UTF8(4)
+	switch firstType {
+	case "styp", // mp4 segment
+		"ftyp", // mp4 file
+		"free", // seems to happen
+		"moov", // seems to happen
+		"pnot", // video preview file
+		"jP  ": // JPEG 2000
+	default:
+		d.Errorf("no styp, ftyp, free or moov box found")
+	}
+
+	d.SeekRel(-8 * 8)
+
+	decodeBoxes(ctx, d)
+	if len(ctx.tracks) > 0 {
+		mp4Tracks(d, ctx)
+	}
 
 	return nil
-
 }
