@@ -40,78 +40,78 @@ const (
 
 // transformed from ffmpeg libavformat/riff.c
 var audioFormatName = scalar.UToSymStr{
-	0x0001: "PCM",
-	0x0002: "ADPCM_MS",
-	0x0003: "PCM_FLOAT",
+	0x0001: "pcm",
+	0x0002: "adpcm_ms",
+	0x0003: "pcm_float",
 	/* must come after f32le in this list */
-	0x0006: "PCM_ALAW",
-	0x0007: "PCM_MULAW",
-	0x000a: "WMAVOICE",
-	0x0010: "ADPCM_IMA_OKI",
-	0x0011: "ADPCM_IMA_WAV",
+	0x0006: "pcm_alaw",
+	0x0007: "pcm_mulaw",
+	0x000a: "wmavoice",
+	0x0010: "adpcm_ima_oki",
+	0x0011: "adpcm_ima_wav",
 	/* must come after adpcm_ima_wav in this list */
-	0x0017: "ADPCM_IMA_OKI",
-	0x0020: "ADPCM_YAMAHA",
-	0x0022: "TRUESPEECH",
-	0x0031: "GSM_MS",
-	0x0032: "GSM_MS", /* msn audio */
-	0x0038: "AMR_NB", /* rogue format number */
-	0x0042: "G723_1",
-	0x0045: "ADPCM_G726",
-	0x0014: "ADPCM_G726", /* g723 Antex */
-	0x0040: "ADPCM_G726", /* g721 Antex */
-	0x0050: "MP2",
-	0x0055: "MP3",
-	0x0057: "AMR_NB",
-	0x0058: "AMR_WB",
+	0x0017: "adpcm_ima_oki",
+	0x0020: "adpcm_yamaha",
+	0x0022: "truespeech",
+	0x0031: "gsm_ms",
+	0x0032: "gsm_ms", /* msn audio */
+	0x0038: "amr_nb", /* rogue format number */
+	0x0042: "g723_1",
+	0x0045: "adpcm_g726",
+	0x0014: "adpcm_g726", /* g723 Antex */
+	0x0040: "adpcm_g726", /* g721 Antex */
+	0x0050: "mp2",
+	0x0055: "mp3",
+	0x0057: "amr_nb",
+	0x0058: "amr_wb",
 	/* rogue format number */
-	0x0061: "ADPCM_IMA_DK4",
+	0x0061: "adpcm_ima_dk4",
 	/* rogue format number */
-	0x0062:           "ADPCM_IMA_DK3",
-	0x0064:           "ADPCM_G726",
-	0x0069:           "ADPCM_IMA_WAV",
-	0x0075:           "METASOUND",
-	0x0083:           "G729",
-	0x00ff:           "AAC",
-	0x0111:           "G723_1",
-	0x0130:           "SIPR",
-	0x0135:           "ACELP_KELVIN",
-	0x0160:           "WMAV1",
-	0x0161:           "WMAV2",
-	0x0162:           "WMAPRO",
-	0x0163:           "WMALOSSLESS",
-	0x0165:           "XMA1",
-	0x0166:           "XMA2",
-	0x0200:           "ADPCM_CT",
-	0x0215:           "DVAUDIO",
-	0x0216:           "DVAUDIO",
-	0x0270:           "ATRAC3",
-	0x028f:           "ADPCM_G722",
-	0x0401:           "IMC",
-	0x0402:           "IAC",
-	0x0500:           "ON2AVC",
-	0x0501:           "ON2AVC",
-	0x1500:           "GSM_MS",
-	0x1501:           "TRUESPEECH",
-	0x1600:           "AAC",
-	0x1602:           "AAC_LATM",
-	0x2000:           "AC3",
-	0x2001:           "DTS",
-	0x2048:           "SONIC",
-	0x6c75:           "PCM_MULAW",
-	0x706d:           "AAC",
-	0x4143:           "AAC",
-	0x594a:           "XAN_DPCM",
-	0x729a:           "G729",
-	0xa100:           "G723_1", /* Comverse Infosys Ltd. G723 1 */
-	0xa106:           "AAC",
-	0xa109:           "SPEEX",
-	0xf1ac:           "FLAC",
-	('S' << 8) + 'F': "ADPCM_SWF",
+	0x0062:           "adpcm_ima_dk3",
+	0x0064:           "adpcm_g726",
+	0x0069:           "adpcm_ima_wav",
+	0x0075:           "metasound",
+	0x0083:           "g729",
+	0x00ff:           "aac",
+	0x0111:           "g723_1",
+	0x0130:           "sipr",
+	0x0135:           "acelp_kelvin",
+	0x0160:           "wmav1",
+	0x0161:           "wmav2",
+	0x0162:           "wmapro",
+	0x0163:           "wmalossless",
+	0x0165:           "xma1",
+	0x0166:           "xma2",
+	0x0200:           "adpcm_ct",
+	0x0215:           "dvaudio",
+	0x0216:           "dvaudio",
+	0x0270:           "atrac3",
+	0x028f:           "adpcm_g722",
+	0x0401:           "imc",
+	0x0402:           "iac",
+	0x0500:           "on2avc",
+	0x0501:           "on2avc",
+	0x1500:           "gsm_ms",
+	0x1501:           "truespeech",
+	0x1600:           "aac",
+	0x1602:           "aac_latm",
+	0x2000:           "ac3",
+	0x2001:           "dts",
+	0x2048:           "sonic",
+	0x6c75:           "pcm_mulaw",
+	0x706d:           "aac",
+	0x4143:           "aac",
+	0x594a:           "xan_dpcm",
+	0x729a:           "g729",
+	0xa100:           "g723_1", /* Comverse Infosys Ltd. G723 1 */
+	0xa106:           "aac",
+	0xa109:           "speex",
+	0xf1ac:           "flac",
+	('S' << 8) + 'F': "adpcm_swf",
 	/* HACK/FIXME: Does Vorbis in WAV/AVI have an (in)official ID? */
-	('V' << 8) + 'o': "VORBIS",
+	('V' << 8) + 'o': "vorbis",
 
-	formatExtensible: "Extensible",
+	formatExtensible: "extensible",
 }
 
 var (
@@ -120,8 +120,8 @@ var (
 )
 
 var subFormatNames = scalar.BytesToScalar{
-	{Bytes: subFormatPCMBytes[:], Scalar: scalar.S{Sym: "PCM"}},
-	{Bytes: subFormatIEEEFloat[:], Scalar: scalar.S{Sym: "IEEE_FLOAT"}},
+	{Bytes: subFormatPCMBytes[:], Scalar: scalar.S{Sym: "pcm"}},
+	{Bytes: subFormatIEEEFloat[:], Scalar: scalar.S{Sym: "ieee_float"}},
 }
 
 func decodeChunk(d *decode.D, expectedChunkID string, stringData bool) int64 { //nolint:unparam
