@@ -48,21 +48,21 @@ const (
 )
 
 var compressionMethodMap = scalar.UToSymStr{
-	compressionMethodNone:                      "None",
-	compressionMethodShrunk:                    "Shrunk",
-	compressionMethodReducedCompressionFactor1: "ReducedCompressionFactor1",
-	compressionMethodReducedCompressionFactor2: "ReducedCompressionFactor2",
-	compressionMethodReducedCompressionFactor3: "ReducedCompressionFactor3",
-	compressionMethodReducedCompressionFactor4: "ReducedCompressionFactor4",
-	compressionMethodImploded:                  "Imploded",
-	compressionMethodDeflated:                  "Deflated",
-	compressionMethodEnhancedDeflated:          "EnhancedDeflated",
-	compressionMethodPKWareDCLImploded:         "PKWareDCLImploded",
-	compressionMethodBzip2:                     "Bzip2",
-	compressionMethodLZMA:                      "LZMA",
-	compressionMethodIBMTERSE:                  "IBMTERSE",
-	compressionMethodIBMLZ77z:                  "IBMLZ77z",
-	compressionMethodPPMd:                      "PPMd",
+	compressionMethodNone:                      "none",
+	compressionMethodShrunk:                    "shrunk",
+	compressionMethodReducedCompressionFactor1: "reduced_compression_factor1",
+	compressionMethodReducedCompressionFactor2: "reduced_compression_factor2",
+	compressionMethodReducedCompressionFactor3: "reduced_compression_factor3",
+	compressionMethodReducedCompressionFactor4: "reduced_compression_factor4",
+	compressionMethodImploded:                  "imploded",
+	compressionMethodDeflated:                  "deflated",
+	compressionMethodEnhancedDeflated:          "enhanced_deflated",
+	compressionMethodPKWareDCLImploded:         "pk_ware_dcl_imploded",
+	compressionMethodBzip2:                     "bzip2",
+	compressionMethodLZMA:                      "lzma",
+	compressionMethodIBMTERSE:                  "ibmterse",
+	compressionMethodIBMLZ77z:                  "ibmlz77z",
+	compressionMethodPPMd:                      "pp_md",
 }
 
 var (
@@ -73,46 +73,46 @@ var (
 	dataIndicatorSignature          = []byte("PK\x07\x08")
 )
 
-var headerIDMap = scalar.UToScalar{
-	0x0001: {Description: "ZIP64 extended information extra field"},
-	0x0007: {Description: "AV Info"},
-	0x0009: {Description: "OS/2 extended attributes"},
-	0x000a: {Description: "NTFS (Win9x/WinNT FileTimes)"},
-	0x000c: {Description: "OpenVMS"},
-	0x000d: {Description: "Unix"},
-	0x000f: {Description: "Patch Descriptor"},
-	0x0014: {Description: "PKCS#7 Store for X.509 Certificates"},
-	0x0015: {Description: "X.509 Certificate ID and Signature for individual file"},
-	0x0016: {Description: "X.509 Certificate ID for Central Directory"},
-	0x0065: {Description: "IBM S/390 attributes - uncompressed"},
-	0x0066: {Description: "IBM S/390 attributes - compressed"},
-	0x07c8: {Description: "Info-ZIP Macintosh (old, J. Lee)"},
-	0x2605: {Description: "ZipIt Macintosh (first version)"},
-	0x2705: {Description: "ZipIt Macintosh v 1.3.5 and newer (w/o full filename)"},
-	0x334d: {Description: "Info-ZIP Macintosh (new, D. Haase's 'Mac3' field )"},
-	0x4154: {Description: "Tandem NSK"},
-	0x4341: {Description: "Acorn/SparkFS (David Pilling)"},
-	0x4453: {Description: "Windows NT security descriptor (binary ACL)"},
-	0x4704: {Description: "VM/CMS"},
-	0x470f: {Description: "MVS"},
+var headerIDMap = scalar.UToDescription{
+	0x0001: "ZIP64 extended information extra field",
+	0x0007: "AV Info",
+	0x0009: "OS/2 extended attributes",
+	0x000a: "NTFS (Win9x/WinNT FileTimes)",
+	0x000c: "OpenVMS",
+	0x000d: "Unix",
+	0x000f: "Patch Descriptor",
+	0x0014: "PKCS#7 Store for X.509 Certificates",
+	0x0015: "X.509 Certificate ID and Signature for individual file",
+	0x0016: "X.509 Certificate ID for Central Directory",
+	0x0065: "IBM S/390 attributes - uncompressed",
+	0x0066: "IBM S/390 attributes - compressed",
+	0x07c8: "Info-ZIP Macintosh (old, J. Lee)",
+	0x2605: "ZipIt Macintosh (first version)",
+	0x2705: "ZipIt Macintosh v 1.3.5 and newer (w/o full filename)",
+	0x334d: "Info-ZIP Macintosh (new, D. Haase's 'Mac3' field )",
+	0x4154: "Tandem NSK",
+	0x4341: "Acorn/SparkFS (David Pilling)",
+	0x4453: "Windows NT security descriptor (binary ACL)",
+	0x4704: "VM/CMS",
+	0x470f: "MVS",
 	// "inofficial" in original table
 	//nolint:misspell
-	0x4854: {Description: "Theos, old inofficial port"},
-	0x4b46: {Description: "FWKCS MD5 (see below)"},
-	0x4c41: {Description: "OS/2 access control list (text ACL)"},
-	0x4d49: {Description: "Info-ZIP OpenVMS (obsolete)"},
-	0x4d63: {Description: "Macintosh SmartZIP, by Macro Bambini"},
-	0x4f4c: {Description: "Xceed original location extra field"},
-	0x5356: {Description: "AOS/VS (binary ACL)"},
-	0x5455: {Description: "extended timestamp"},
-	0x5855: {Description: "Info-ZIP Unix (original; also OS/2, NT, etc.)"},
-	0x554e: {Description: "Xceed unicode extra field"},
-	0x6542: {Description: "BeOS (BeBox, PowerMac, etc.)"},
-	0x6854: {Description: "Theos"},
-	0x756e: {Description: "ASi Unix"},
-	0x7855: {Description: "Info-ZIP Unix (new)"},
-	0x7875: {Description: "UNIX UID/GID"},
-	0xfb4a: {Description: "SMS/QDOS"},
+	0x4854: "Theos, old inofficial port",
+	0x4b46: "FWKCS MD5 (see below)",
+	0x4c41: "OS/2 access control list (text ACL)",
+	0x4d49: "Info-ZIP OpenVMS (obsolete)",
+	0x4d63: "Macintosh SmartZIP, by Macro Bambini",
+	0x4f4c: "Xceed original location extra field",
+	0x5356: "AOS/VS (binary ACL)",
+	0x5455: "extended timestamp",
+	0x5855: "Info-ZIP Unix (original; also OS/2, NT, etc.)",
+	0x554e: "Xceed unicode extra field",
+	0x6542: "BeOS (BeBox, PowerMac, etc.)",
+	0x6854: "Theos",
+	0x756e: "ASi Unix",
+	0x7855: "Info-ZIP Unix (new)",
+	0x7875: "UNIX UID/GID",
+	0xfb4a: "SMS/QDOS",
 }
 
 // "MS-DOS uses year values relative to 1980 and 2 second precision."
@@ -278,9 +278,7 @@ func zipDecode(d *decode.D, in interface{}) interface{} {
 				}
 
 				if compressionMethod == compressionMethodNone {
-					if dv, _, _ := d.TryFieldFormatLen("uncompressed", compressedSize, probeFormat, nil); dv == nil {
-						d.FieldRawLen("uncompressed", compressedSize)
-					}
+					d.FieldFormatOrRawLen("uncompressed", compressedSize, probeFormat, nil)
 				} else {
 					var rFn func(r io.Reader) io.Reader
 					switch compressionMethod {
