@@ -1,13 +1,13 @@
 package interp
 
 import (
-	"bytes"
 	"errors"
 	"fmt"
 	"io"
 	"strconv"
 	"strings"
 
+	"github.com/wader/fq/internal/ansi"
 	"github.com/wader/fq/internal/asciiwriter"
 	"github.com/wader/fq/internal/bitioextra"
 	"github.com/wader/fq/internal/columnwriter"
@@ -18,6 +18,12 @@ import (
 	"github.com/wader/fq/pkg/scalar"
 )
 
+// TODO: refactor this
+// move more things to jq?
+// select columns?
+// smart line wrap instead of truncate?
+// binary/octal/... dump?
+
 // 0   12      34    56
 // addr|hexdump|ascii|field
 const (
@@ -36,7 +42,7 @@ func isCompound(v *decode.Value) bool {
 	}
 }
 
-func dumpEx(v *decode.Value, buf []byte, cw *columnwriter.Writer, depth int, rootV *decode.Value, rootDepth int, addrWidth int, opts Options) error {
+func dumpEx(v *decode.Value, buf []byte, cw *columnwriter.Writer, depth int, rootV *decode.Value, rootDepth int, addrWidth int, opts *Options) error {
 	deco := opts.Decorator
 	// no error check as we write into buffering column
 	// we check for err later for Flush()
@@ -82,7 +88,7 @@ func dumpEx(v *decode.Value, buf []byte, cw *columnwriter.Writer, depth int, roo
 		name = ""
 	}
 	if depth == 0 {
-		name = valuePathDecorated(nameV, deco)
+		name = valuePathExprDecorated(nameV, deco)
 	} else {
 		name = deco.ObjectKey.Wrap(name)
 	}
@@ -131,7 +137,7 @@ func dumpEx(v *decode.Value, buf []byte, cw *columnwriter.Writer, depth int, roo
 			cfmt(colField, "%s", deco.Object.F("{}"))
 		}
 		cprint(colField, ":")
-		if opts.Verbose && isInArray {
+		if isInArray {
 			cfmt(colField, " %s", v.Name)
 		}
 		if vv.Description != "" {
@@ -356,32 +362,35 @@ func dump(v *decode.Value, w io.Writer, opts Options) error {
 		return nil
 	}))
 
-	cw := columnwriter.New(w, []int{maxAddrIndentWidth, 1, opts.LineBytes*3 - 1, 1, opts.LineBytes, 1, -1})
+	cw := columnwriter.New(
+		w,
+		[]int{
+			maxAddrIndentWidth,
+			1,
+			opts.LineBytes*3 - 1,
+			1,
+			opts.LineBytes,
+			1,
+			-1,
+		})
 	buf := make([]byte, 32*1024)
 
+	if opts.Color {
+		cw.LenFn = ansi.Len
+		cw.TruncateFn = ansi.Truncate
+	}
+
 	return v.WalkPreOrder(makeWalkFn(func(v *decode.Value, rootV *decode.Value, depth int, rootDepth int) error {
-		return dumpEx(v, buf, cw, depth, rootV, rootDepth, maxAddrIndentWidth-rootDepth, opts)
+		return dumpEx(v, buf, cw, depth, rootV, rootDepth, maxAddrIndentWidth-rootDepth, &opts)
 	}))
 }
 
 func hexdump(w io.Writer, bv Binary, opts Options) error {
-	br, err := bv.toReader()
+	br, err := bitioextra.Range(bv.br, bv.r.Start, bv.r.Len)
 	if err != nil {
 		return err
 	}
 
-	cBR, err := bitioextra.Clone(bv.br)
-	if err != nil {
-		return err
-	}
-
-	bytesB := &bytes.Buffer{}
-	if _, err := bitioextra.CopyBits(bytesB, cBR); err != nil {
-		return err
-	}
-
-	biib := bitio.NewBitReader(bytesB.Bytes(), -1)
-
 	// TODO: hack
 	opts.Verbose = true
 	return dump(
@@ -389,7 +398,7 @@ func hexdump(w io.Writer, bv Binary, opts Options) error {
 			// TODO: hack
 			V:          &scalar.S{Actual: br},
 			Range:      bv.r,
-			RootReader: biib,
+			RootReader: bv.br,
 		},
 		w,
 		opts,
